alias

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExpandAliasArgs

func ExpandAliasArgs(root *cobra.Command, args []string) ([]string, error)

ExpandAliasArgs rewrites argv so a leading alias name is replaced by its configured expansion before cobra dispatches the command.

func NewCommand

func NewCommand() *cobra.Command

NewCommand returns the `alias` command group for managing command aliases.

Types

This section is empty.

Jump to