Documentation
¶
Overview ¶
Package update implements the `jira update` cobra command, which self-updates a release-archive binary in place and points Scoop and go-install binaries at the command their channel manages updates with.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCommand ¶
NewCommand returns the `update` command: self-update for release-archive installs, channel-specific update hints for Scoop and go-install binaries.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.